@@ -70,6 +70,9 @@ public interface TdTemplateConstants {
 	public static String CREATE_TIME_DIMENSION = "Create Time Dimension";
 	public static String NORMALIZE = "Normalize";
 	public static String NORMALIZE_COLUMNS_ACTION = "Normalize Columns Action";
+	public static final String ADD_A_MULTI_COLUMN_RULE = "Add a multi-column rule";
+	public static final String TABLE_RULE = "Table Rule";
+
 	/**
 	 * Used by {@link TemplatePanel}
 	 */
